# Guardion.AI SDK

## How to use?

### OpenAI Agents SDK

You need to install our SDK using our openai-agents extras with the following command:

```bash
pip install guardionsdk[openai_agents]
```

And use it as shown in the file `examples/openai_agents.sdk`.

### LangChain

We support Chat and simple LLM models from LangChain, in order to use it, you need to install our langchain extra.

```bash
pip install guardionsdk[langchain]
```

And in order to use it, just checkout our `examples/langhchain.py` file.